| Title: | 'Shiny' Application for R Package 'fitODBOD' |
|---|---|
| Description: | For binomial outcome data Alternate Binomial Distributions and Binomial Mixture Distributions are fitted when overdispersion is available. |
| Authors: | Amalan Mahendran [cre, aut] |
| Maintainer: | Amalan Mahendran <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.2 |
| Built: | 2026-06-01 10:56:00 UTC |
| Source: | https://github.com/Amalan-ConStat/fitODBODRshiny |
Data for the Rshiny application are stored here. The data consists a list of plots for Alternate Binomial and Binomial Mixture distributions modelled on the datasets from the R package "fitODBOD". Each element here consists seven elements representing the seven datasets.
All_PlotsAll_Plots
A list with
All_DataAll Datasets with binomial random variables and their frequencies
ABD_TableTable results from the Alternate Binomial distribution
BMD_TableTable results from the Binomial Mixture distributions
Bin_PlotPlot for the fitted Binomial distribution
Add_Bin_PlotFrequency plot for the fitted Additive Binomial distribution
Beta_Corr_Bin_Freq_PlotFrequency plot for the fitted Beta Correlated Binomial distribution
Beta_Corr_Bin_Par_PlotParameter plot for the fitted Beta Correlated Binomial distribution
COMP_Bin_Freq_PlotFrequency plot for the fitted Composite Binomial distribution
COMP_Bin_Par_PlotParameter plot for the fitted Composite Binomial distribution
Corr_Bin_Freq_PlotFrequency plot for the fitted Correlated Binomial distribution
Corr_Bin_Par_PlotParameter plot for the fitted Correlated Binomial distribution
Multi_Bin_Freq_PlotFrequency plot for the fitted Multiplicative Binomial distribution
Multi_Bin_Par_PlotParameter plot for the fitted Multiplicative Binomial distribution
LMulti_Bin_Freq_PlotFrequency plot for the fitted Lovinson Multiplicative Binomial distribution
LMulti_Bin_Par_PlotParameter plot for the fitted Lovinson Multiplicative Binomial distribution
Tri_Bin_PlotFrequency plot for the fitted Triangular Binomial distribution
Beta_Bin_Freq_PlotFrequency plot for the fitted Beta Binomial distribution
Beta_Bin_Par_PlotParameter plot for the fitted Beta Binomial distribution
Kum_Bin_Freq_PlotFrequency plot for the fitted Kumaraswamy Binomial distribution
Kum_Bin_Par_PlotParameter plot for the fitted Kumaraswamy Binomial distribution
Gam_Bin_Freq_PlotFrequency plot for the fitted Gamma Binomial distribution
Gam_Bin_Par_PlotParameter plot for the fitted Gamma Binomial distribution
Grassia_Bin_Freq_PlotFrequency plot for the fitted Grassia II Binomial distribution
Grassia_Bin_Par_PlotParameter plot for the fitted Grassia II Binomial distribution
GHGBeta_Bin_Freq_PlotFrequency plot for the fitted Gaussian Hypergeometric Generalized Beta Binomial distribution
GHGBeta_Bin_Par_PlotParameter plot for the fitted Gaussian Hypergeometric Generalized Beta Binomial distribution
McGBB_Bin_Freq_PlotFrequency plot for the fitted McDonald Generalized Beta Binomial distribution
McGBB_Bin_Par_PlotParameter plot for the fitted McDonald Generalized Beta Binomial distribution
length(All_Plots$Bin_Plots) # No of plots in the list for all 7 datasets length(All_Plots$All_Data) # 7 datasetslength(All_Plots$Bin_Plots) # No of plots in the list for all 7 datasets length(All_Plots$All_Data) # 7 datasets
Run the Shiny Application
run_app(...)run_app(...)
... |
list of golem options. |
used for side effects